# This script was written by Noam Rathaus <noamr@securiteam.com>
# Thanks to  Haroon Meer <haroon@sensepost.com>

# Description part

if(description)
{
 script_name(english:"Checkpoint SecuRemote information leakage");

 script_id(10710);

desc["english"] = "
The remote host seems to be a Checkpoint FireWall-1 running SecuRemote.
The SecuRemote service contains a vulnerability that allows attackers
to gain information about the hosts, networks, and users configured on 
the Firewall.

This will enable attackers to focus their attack strategy.

You should not let this information leak out.

Solution:
Either block the SecuRemote's ports (TCP 256 and 264) to untrusted networks, 
or upgrade to the latest version of Checkpoint's Firewall-1.

Workaround:
You could restrict the topology download, so that only authenticated 
users can download it.
Go to Policy Properties Desktop Security of your Policy Editor and 
uncheck 'respond to unauthenticated topology requests'.
After installing the Policy only authenticated Users can download 
the Topology.

Risk Factor: Medium

For More Information:
http://www.securiteam.com/securitynews/5HP0D2A4UC.html";


 script_description(english:desc["english"]);
 script_summary(english:"Checkpoint SecuRemote information leakage");
 script_category(ACT_GATHER_INFO);
 script_family(english:"Firewalls");
 script_copyright(english:"This script is Copyright (C) 2001 SecuriTeam");
 script_dependencies("find_service.nes");
 script_require_ports(256, 264);
 exit(0);
}

securemote_request_info = raw_string(
0x41, 0x00, 0x00, 0x00, 0x02, 0x59, 0x05, 0x21, 0x00, 0x00, 0x00, 0x04, 0x0a, 0x00,
0x00, 0x03, 0x00, 0x00, 0x00, 0x6e, 0x28, 0x74, 0x6F, 0x70, 0x6F, 0x6C, 0x6F, 0x67, 0x79, 0x2D, 0x72, 0x65, 0x71, 0x75, 0x65,
0x73, 0x74, 0x0A, 0x09, 0x3A, 0x63, 0x61, 0x6E, 0x61, 0x6D, 0x65, 0x20, 0x28, 0x32, 0x30, 0x39, 0x2E, 0x31, 0x31, 0x2E, 0x38, 
0x2E, 0x32, 0x35, 0x34, 0x29, 0x0A, 0x09, 0x3A, 0x73, 0x69, 0x67, 0x6E, 0x68, 0x61, 0x73, 0x68, 0x20, 0x28, 0x38, 0x31, 0x32, 
0x39, 0x38, 0x64, 0x33, 0x37, 0x35, 0x35, 0x31, 0x36, 0x32, 0x33, 0x32, 0x39, 0x61, 0x62, 0x33, 0x35, 0x35, 0x34, 0x30, 0x64, 
0x29, 0x0A, 0x09, 0x3A, 0x63, 0x68, 0x61, 0x6C, 0x6C, 0x65, 0x6E, 0x67, 0x65, 0x20, 0x28, 0x65, 0x37, 0x38, 0x66, 0x31, 0x37, 
0x65, 0x35, 0x32, 0x63, 0x39, 0x30, 0x29, 0x0A, 0x29, 0x0A, 0x00, 0x00);


port = 0;
if (get_port_state(264))
{
 soc = open_sock_tcp(264);
 if(soc)
  {
   close(soc);
   port = 264;
   }
}

if(!port)
{
if (get_port_state(256))
 {
  port = 256;
 }
}

if (port)
{
 soc = open_sock_tcp(port);
 if (soc)
 {
  send (socket:soc, data:securemote_request_info);
  response = recv(socket:soc, length:8192);
  if (":reply" >< response)
  {
   len = strlen(response);
   loc = 0;
   for(i=0;i<len;i=i+1)
   {
    if(response[i] == raw_string(0x28))
    {
    loc = i;
    i = len + 1;
    }
   }

   response_filtered = "";
   for (i = loc; i < len; i = i + 1)
   {
    if (response[i] == raw_string(0x09))
    {
     response_filtered = string(response_filtered, " ");
    }
    else
    {
     response_filtered = string(response_filtered, response[i]);
    }
   }
   report = string(
"The remote host seems to be a Checkpoint FireWall-1 running SecuRemote.\n",
"The SecuRemote service contains a vulnerability that allows attackers\n",
"to gain information about the hosts, networks, and users configured on\n",
"the Firewall.\n\n",
"This will enable attackers to focus their attack strategy.\n",
"You should not let this information leak out.\n", 
"Here is the gathered data :\n\n",
response_filtered,
"\n\n",
"Solution: Either block the SecuRemote's ports (TCP 256 and 264) to untrusted networks,\n",
"or upgrade to the latest version of Checkpoint's Firewall-1.\n\n",
"Workaround: You could restrict the topology download, so that only authenticated\n",
"users can download it.\n",
"Go to Policy Properties Desktop Security of your Policy Editor and \n",
"uncheck 'respond to unauthenticated topology requests'.\n",
"After installing the Policy only authenticated Users can download \n",
"the Topology.\n\n",
"Risk Factor: Medium\n",
"For More Information:\n",
"http://www.securiteam.com/securitynews/5HP0D2A4UC.html");
   security_hole(port:port, data:report);
   set_kb_item("host/firewall", "Checkpoint Firewall-1");
  }
 }
}
